Learn R Programming

pomodoro (version 3.8.0)

GBM_Model: Gradient Boosting Model

Description

Gradient Boosting Model

Usage

GBM_Model(Data, xvar, yvar)

Arguments

Data

The name of the Dataset.

xvar

X variables.

yvar

Y variable.

Value

The output from GBM_Model.

Details

Unlike bagging trees, boosting does not use bootstrap sampling, rather each tree is fit using information from previous trees. An event probability of stochastic gradient boosting model is given by $$\hat{\pi_i} = \frac{1}{1 + exp[-f(x)]^\prime}$$ where \(f(x)\) is in the range of \([-\infty,\infty]\) and its initial estimate of the model is \(f^{(0)}_i=log(\frac{\pi_{i}}{1-\pi_{i}})\), where \(\hat{\pi}\) is the estimated sample proportion of a single class from the training set.

Examples

Run this code
# NOT RUN {
yvar <- c("Loan.Type")
sample_data <- sample_data[c(1:120),]
xvar <- c("sex", "married", "age", "havejob", "educ", "political.afl",
"rural", "region", "fin.intermdiaries", "fin.knowldge", "income")
BchMk.GBM <- GBM_Model(sample_data, c(xvar, "networth"), yvar )
BchMk.GBM$finalModel
BchMk.GBM$Roc$auc
# }

Run the code above in your browser using DataLab